{% extends "page_special.html" %} {% block page_title %}

# {{ _("Recent changes") }}

{% endblock %} {% block title %}{{ _("Recent changes") }} - {{ wiki.site_name }}{% endblock %} {% block content %}

{% for date, date_url, title, author, comment in changes %}
- {{ date_html(date)|safe }} {{ page.wiki_link(title)|safe }} . . . . {{ page.wiki_link("~%s" % author, author)|safe }}
  {{ comment }}
{% endfor %}

{% endblock %}